/****************************************************************************
** GUI_Playlist meta object code from reading C++ file 'gui_playlist.h'
**
** Created: Sat Jan 6 23:56:09 2007
**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.6   edited Mar 8 17:43 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#undef QT_NO_COMPAT
#include "gui_playlist.h"
#include <qmetaobject.h>
#include <qapplication.h>

#include <private/qucomextra_p.h>
#if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
#error "This file was generated using the moc from 3.3.6. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

const char *GUI_Playlist::className() const
{
    return "GUI_Playlist";
}

QMetaObject *GUI_Playlist::metaObj = 0;
static QMetaObjectCleanUp cleanUp_GUI_Playlist( "GUI_Playlist", &GUI_Playlist::staticMetaObject );

#ifndef QT_NO_TRANSLATION
QString GUI_Playlist::tr( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "GUI_Playlist", s, c, QApplication::DefaultCodec );
    else
	return QString::fromLatin1( s );
}
#ifndef QT_NO_TRANSLATION_UTF8
QString GUI_Playlist::trUtf8( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "GUI_Playlist", s, c, QApplication::UnicodeUTF8 );
    else
	return QString::fromUtf8( s );
}
#endif // QT_NO_TRANSLATION_UTF8

#endif // QT_NO_TRANSLATION

QMetaObject* GUI_Playlist::staticMetaObject()
{
    if ( metaObj )
	return metaObj;
    QMetaObject* parentObject = QTabWidget::staticMetaObject();
    static const QUParameter param_slot_0[] = {
	{ "state", &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod slot_0 = {"slot_setConnectionState", 1, param_slot_0 };
    static const QUMethod slot_1 = {"slot_newButton", 0, 0 };
    static const QUMethod slot_2 = {"slot_importPlaylist", 0, 0 };
    static const QUMethod slot_3 = {"slot_refreshFromInternetButton", 0, 0 };
    static const QUMethod slot_4 = {"slot_abortRefreshFromInternetButton", 0, 0 };
    static const QUMethod slot_5 = {"slot_generateButton", 0, 0 };
    static const QUMethod slot_6 = {"slot_resetButton", 0, 0 };
    static const QUParameter param_slot_7[] = {
	{ 0, &static_QUType_int, 0, QUParameter::In }
    };
    static const QUMethod slot_7 = {"slot_generatorMinTrackLength", 1, param_slot_7 };
    static const QUParameter param_slot_8[] = {
	{ 0, &static_QUType_int, 0, QUParameter::In }
    };
    static const QUMethod slot_8 = {"slot_generatorMaxTrackLength", 1, param_slot_8 };
    static const QUMethod slot_9 = {"slot_movePlaylistTrackUp", 0, 0 };
    static const QUMethod slot_10 = {"slot_movePlaylistTrackDown", 0, 0 };
    static const QUMethod slot_11 = {"slot_savePlaylistTracks", 0, 0 };
    static const QUMethod slot_12 = {"slot_menuPlaylistToSelection", 0, 0 };
    static const QUParameter param_slot_13[] = {
	{ 0, &static_QUType_ptr, "QListViewItem", QUParameter::In },
	{ 0, &static_QUType_varptr, "\x0e", QUParameter::In },
	{ 0, &static_QUType_int, 0, QUParameter::In }
    };
    static const QUMethod slot_13 = {"slot_contextMenu", 3, param_slot_13 };
    static const QUMethod slot_14 = {"slot_menuAddPlaylistToCurrent", 0, 0 };
    static const QUMethod slot_15 = {"slot_menuRemovePlaylistTracks", 0, 0 };
    static const QUMethod slot_16 = {"slot_menuPlayPlaylist", 0, 0 };
    static const QUMethod slot_17 = {"slot_menuEnqueuePlaylist", 0, 0 };
    static const QUMethod slot_18 = {"slot_menuBurnCD", 0, 0 };
    static const QUMethod slot_19 = {"slot_menuBurnK3bAudioCD", 0, 0 };
    static const QUMethod slot_20 = {"slot_menuBurnK3bDataCD", 0, 0 };
    static const QUMethod slot_21 = {"slot_menuBurnK3bDataDVD", 0, 0 };
    static const QUMethod slot_22 = {"slot_menuExport", 0, 0 };
    static const QUMethod slot_23 = {"slot_menuCopyFiles", 0, 0 };
    static const QUMethod slot_24 = {"slot_menuRemovePlaylist", 0, 0 };
    static const QUMethod slot_25 = {"slot_menuRenamePlaylist", 0, 0 };
    static const QUMethod slot_26 = {"slot_menuPlayPlaylistTracks", 0, 0 };
    static const QUMethod slot_27 = {"slot_menuEnqueuePlaylistTracks", 0, 0 };
    static const QUMethod slot_28 = {"slot_menuPrelistenPlaylistTracks", 0, 0 };
    static const QUMethod slot_29 = {"slot_mixxxLoadAtChannel1", 0, 0 };
    static const QUMethod slot_30 = {"slot_mixxxLoadAtChannel2", 0, 0 };
    static const QUMethod slot_31 = {"slot_mixxxLoadAndPlayAtChannel1", 0, 0 };
    static const QUMethod slot_32 = {"slot_mixxxLoadAndPlayAtChannel2", 0, 0 };
    static const QUMethod slot_33 = {"slot_mixxxEnqueueTracksAtChannel1", 0, 0 };
    static const QUMethod slot_34 = {"slot_mixxxEnqueueTracksAtChannel2", 0, 0 };
    static const QUMethod slot_35 = {"slot_menuEnqueuePlaylistAtChannel1", 0, 0 };
    static const QUMethod slot_36 = {"slot_menuEnqueuePlaylistAtChannel2", 0, 0 };
    static const QUParameter param_slot_37[] = {
	{ 0, &static_QUType_ptr, "QListViewItem", QUParameter::In }
    };
    static const QUMethod slot_37 = {"slot_playlistSelectionChanged", 1, param_slot_37 };
    static const QUMethod slot_38 = {"slot_trackSelectionChanged", 0, 0 };
    static const QUParameter param_slot_39[] = {
	{ 0, &static_QUType_ptr, "QWidget", QUParameter::In }
    };
    static const QUMethod slot_39 = {"slot_tabChange", 1, param_slot_39 };
    static const QUParameter param_slot_40[] = {
	{ "lvi", &static_QUType_ptr, "QListViewItem", QUParameter::In }
    };
    static const QUMethod slot_40 = {"slot_playlistDoubleClicked", 1, param_slot_40 };
    static const QUParameter param_slot_41[] = {
	{ "lvi", &static_QUType_ptr, "QListViewItem", QUParameter::In }
    };
    static const QUMethod slot_41 = {"slot_playlistTrackDoubleClicked", 1, param_slot_41 };
    static const QUMethod slot_42 = {"slot_ClickLyrics", 0, 0 };
    static const QUMethod slot_43 = {"slot_ClickReview", 0, 0 };
    static const QUMethod slot_44 = {"slot_ClickTracks", 0, 0 };
    static const QUMethod slot_45 = {"slot_ClickBiography", 0, 0 };
    static const QUMethod slot_46 = {"slot_ClickMexlog", 0, 0 };
    static const QUParameter param_slot_47[] = {
	{ 0, &static_QUType_int, 0, QUParameter::In }
    };
    static const QUMethod slot_47 = {"slot_changeLyricsRadio", 1, param_slot_47 };
    static const QUParameter param_slot_48[] = {
	{ "lst", &static_QUType_ptr, "QPtrList<QNetworkOperation>", QUParameter::In }
    };
    static const QUMethod slot_48 = {"slot_startedNextCopy", 1, param_slot_48 };
    static const QMetaData slot_tbl[] = {
	{ "slot_setConnectionState(bool)", &slot_0, QMetaData::Public },
	{ "slot_newButton()", &slot_1, QMetaData::Private },
	{ "slot_importPlaylist()", &slot_2, QMetaData::Private },
	{ "slot_refreshFromInternetButton()", &slot_3, QMetaData::Private },
	{ "slot_abortRefreshFromInternetButton()", &slot_4, QMetaData::Private },
	{ "slot_generateButton()", &slot_5, QMetaData::Private },
	{ "slot_resetButton()", &slot_6, QMetaData::Private },
	{ "slot_generatorMinTrackLength(int)", &slot_7, QMetaData::Private },
	{ "slot_generatorMaxTrackLength(int)", &slot_8, QMetaData::Private },
	{ "slot_movePlaylistTrackUp()", &slot_9, QMetaData::Private },
	{ "slot_movePlaylistTrackDown()", &slot_10, QMetaData::Private },
	{ "slot_savePlaylistTracks()", &slot_11, QMetaData::Private },
	{ "slot_menuPlaylistToSelection()", &slot_12, QMetaData::Private },
	{ "slot_contextMenu(QListViewItem*,const QPoint&,int)", &slot_13, QMetaData::Private },
	{ "slot_menuAddPlaylistToCurrent()", &slot_14, QMetaData::Private },
	{ "slot_menuRemovePlaylistTracks()", &slot_15, QMetaData::Private },
	{ "slot_menuPlayPlaylist()", &slot_16, QMetaData::Private },
	{ "slot_menuEnqueuePlaylist()", &slot_17, QMetaData::Private },
	{ "slot_menuBurnCD()", &slot_18, QMetaData::Private },
	{ "slot_menuBurnK3bAudioCD()", &slot_19, QMetaData::Private },
	{ "slot_menuBurnK3bDataCD()", &slot_20, QMetaData::Private },
	{ "slot_menuBurnK3bDataDVD()", &slot_21, QMetaData::Private },
	{ "slot_menuExport()", &slot_22, QMetaData::Private },
	{ "slot_menuCopyFiles()", &slot_23, QMetaData::Private },
	{ "slot_menuRemovePlaylist()", &slot_24, QMetaData::Private },
	{ "slot_menuRenamePlaylist()", &slot_25, QMetaData::Private },
	{ "slot_menuPlayPlaylistTracks()", &slot_26, QMetaData::Private },
	{ "slot_menuEnqueuePlaylistTracks()", &slot_27, QMetaData::Private },
	{ "slot_menuPrelistenPlaylistTracks()", &slot_28, QMetaData::Private },
	{ "slot_mixxxLoadAtChannel1()", &slot_29, QMetaData::Private },
	{ "slot_mixxxLoadAtChannel2()", &slot_30, QMetaData::Private },
	{ "slot_mixxxLoadAndPlayAtChannel1()", &slot_31, QMetaData::Private },
	{ "slot_mixxxLoadAndPlayAtChannel2()", &slot_32, QMetaData::Private },
	{ "slot_mixxxEnqueueTracksAtChannel1()", &slot_33, QMetaData::Private },
	{ "slot_mixxxEnqueueTracksAtChannel2()", &slot_34, QMetaData::Private },
	{ "slot_menuEnqueuePlaylistAtChannel1()", &slot_35, QMetaData::Private },
	{ "slot_menuEnqueuePlaylistAtChannel2()", &slot_36, QMetaData::Private },
	{ "slot_playlistSelectionChanged(QListViewItem*)", &slot_37, QMetaData::Private },
	{ "slot_trackSelectionChanged()", &slot_38, QMetaData::Private },
	{ "slot_tabChange(QWidget*)", &slot_39, QMetaData::Private },
	{ "slot_playlistDoubleClicked(QListViewItem*)", &slot_40, QMetaData::Private },
	{ "slot_playlistTrackDoubleClicked(QListViewItem*)", &slot_41, QMetaData::Private },
	{ "slot_ClickLyrics()", &slot_42, QMetaData::Private },
	{ "slot_ClickReview()", &slot_43, QMetaData::Private },
	{ "slot_ClickTracks()", &slot_44, QMetaData::Private },
	{ "slot_ClickBiography()", &slot_45, QMetaData::Private },
	{ "slot_ClickMexlog()", &slot_46, QMetaData::Private },
	{ "slot_changeLyricsRadio(int)", &slot_47, QMetaData::Private },
	{ "slot_startedNextCopy(const QPtrList<QNetworkOperation>&)", &slot_48, QMetaData::Private }
    };
    metaObj = QMetaObject::new_metaobject(
	"GUI_Playlist", parentObject,
	slot_tbl, 49,
	0, 0,
#ifndef QT_NO_PROPERTIES
	0, 0,
	0, 0,
#endif // QT_NO_PROPERTIES
	0, 0 );
    cleanUp_GUI_Playlist.setMetaObject( metaObj );
    return metaObj;
}

void* GUI_Playlist::qt_cast( const char* clname )
{
    if ( !qstrcmp( clname, "GUI_Playlist" ) )
	return this;
    return QTabWidget::qt_cast( clname );
}

bool GUI_Playlist::qt_invoke( int _id, QUObject* _o )
{
    switch ( _id - staticMetaObject()->slotOffset() ) {
    case 0: slot_setConnectionState((bool)static_QUType_bool.get(_o+1)); break;
    case 1: slot_newButton(); break;
    case 2: slot_importPlaylist(); break;
    case 3: slot_refreshFromInternetButton(); break;
    case 4: slot_abortRefreshFromInternetButton(); break;
    case 5: slot_generateButton(); break;
    case 6: slot_resetButton(); break;
    case 7: slot_generatorMinTrackLength((int)static_QUType_int.get(_o+1)); break;
    case 8: slot_generatorMaxTrackLength((int)static_QUType_int.get(_o+1)); break;
    case 9: slot_movePlaylistTrackUp(); break;
    case 10: slot_movePlaylistTrackDown(); break;
    case 11: slot_savePlaylistTracks(); break;
    case 12: slot_menuPlaylistToSelection(); break;
    case 13: slot_contextMenu((QListViewItem*)static_QUType_ptr.get(_o+1),(const QPoint&)*((const QPoint*)static_QUType_ptr.get(_o+2)),(int)static_QUType_int.get(_o+3)); break;
    case 14: slot_menuAddPlaylistToCurrent(); break;
    case 15: slot_menuRemovePlaylistTracks(); break;
    case 16: slot_menuPlayPlaylist(); break;
    case 17: slot_menuEnqueuePlaylist(); break;
    case 18: slot_menuBurnCD(); break;
    case 19: slot_menuBurnK3bAudioCD(); break;
    case 20: slot_menuBurnK3bDataCD(); break;
    case 21: slot_menuBurnK3bDataDVD(); break;
    case 22: slot_menuExport(); break;
    case 23: slot_menuCopyFiles(); break;
    case 24: slot_menuRemovePlaylist(); break;
    case 25: slot_menuRenamePlaylist(); break;
    case 26: slot_menuPlayPlaylistTracks(); break;
    case 27: slot_menuEnqueuePlaylistTracks(); break;
    case 28: slot_menuPrelistenPlaylistTracks(); break;
    case 29: slot_mixxxLoadAtChannel1(); break;
    case 30: slot_mixxxLoadAtChannel2(); break;
    case 31: slot_mixxxLoadAndPlayAtChannel1(); break;
    case 32: slot_mixxxLoadAndPlayAtChannel2(); break;
    case 33: slot_mixxxEnqueueTracksAtChannel1(); break;
    case 34: slot_mixxxEnqueueTracksAtChannel2(); break;
    case 35: slot_menuEnqueuePlaylistAtChannel1(); break;
    case 36: slot_menuEnqueuePlaylistAtChannel2(); break;
    case 37: slot_playlistSelectionChanged((QListViewItem*)static_QUType_ptr.get(_o+1)); break;
    case 38: slot_trackSelectionChanged(); break;
    case 39: slot_tabChange((QWidget*)static_QUType_ptr.get(_o+1)); break;
    case 40: slot_playlistDoubleClicked((QListViewItem*)static_QUType_ptr.get(_o+1)); break;
    case 41: slot_playlistTrackDoubleClicked((QListViewItem*)static_QUType_ptr.get(_o+1)); break;
    case 42: slot_ClickLyrics(); break;
    case 43: slot_ClickReview(); break;
    case 44: slot_ClickTracks(); break;
    case 45: slot_ClickBiography(); break;
    case 46: slot_ClickMexlog(); break;
    case 47: slot_changeLyricsRadio((int)static_QUType_int.get(_o+1)); break;
    case 48: slot_startedNextCopy((const QPtrList<QNetworkOperation>&)*((const QPtrList<QNetworkOperation>*)static_QUType_ptr.get(_o+1))); break;
    default:
	return QTabWidget::qt_invoke( _id, _o );
    }
    return TRUE;
}

bool GUI_Playlist::qt_emit( int _id, QUObject* _o )
{
    return QTabWidget::qt_emit(_id,_o);
}
#ifndef QT_NO_PROPERTIES

bool GUI_Playlist::qt_property( int id, int f, QVariant* v)
{
    return QTabWidget::qt_property( id, f, v);
}

bool GUI_Playlist::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
#endif // QT_NO_PROPERTIES
